==> kubernetes-model-gatewayapi-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayStatusFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayStatusFluent<A extends GatewayStatusFluent<A>> extends Fluent<A>{
  public A addToAddresses(Integer index,GatewayAddress item);
  public A setToAddresses(Integer index,GatewayAddress item);
  public A addToAddresses(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewayAddress... items);
  public A addAllToAddresses(Collection<GatewayAddress> items);
  public A removeFromAddresses(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewayAddress... items);
  public A removeAllFromAddresses(Collection<GatewayAddress> items);
  public A removeMatchingFromAddresses(Predicate<GatewayAddressBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAddresses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GatewayAddress> getAddresses();
  public List<GatewayAddress> buildAddresses();
  public GatewayAddress buildAddress(Integer index);
  public GatewayAddress buildFirstAddress();
  public GatewayAddress buildLastAddress();
  public GatewayAddress buildMatchingAddress(Predicate<GatewayAddressBuilder> predicate);
  public Boolean hasMatchingAddress(Predicate<GatewayAddressBuilder> predicate);
  public A withAddresses(List<GatewayAddress> addresses);
  public A withAddresses(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewayAddress... addresses);
  public Boolean hasAddresses();
  public A addNewAddress(String type,String value);
  public GatewayStatusFluent.AddressesNested<A> addNewAddress();
  public GatewayStatusFluent.AddressesNested<A> addNewAddressLike(GatewayAddress item);
  public GatewayStatusFluent.AddressesNested<A> setNewAddressLike(Integer index,GatewayAddress item);
  public GatewayStatusFluent.AddressesNested<A> editAddress(Integer index);
  public GatewayStatusFluent.AddressesNested<A> editFirstAddress();
  public GatewayStatusFluent.AddressesNested<A> editLastAddress();
  public GatewayStatusFluent.AddressesNested<A> editMatchingAddress(Predicate<GatewayAddressBuilder> predicate);
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public List<Condition> getConditions();
  public Condition getCondition(Integer index);
  public Condition getFirstCondition();
  public Condition getLastCondition();
  public Condition getMatchingCondition(Predicate<Condition> predicate);
  public Boolean hasMatchingCondition(Predicate<Condition> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions);
  public Boolean hasConditions();
  public A addToListeners(Integer index,ListenerStatus item);
  public A setToListeners(Integer index,ListenerStatus item);
  public A addToListeners(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ListenerStatus... items);
  public A addAllToListeners(Collection<ListenerStatus> items);
  public A removeFromListeners(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ListenerStatus... items);
  public A removeAllFromListeners(Collection<ListenerStatus> items);
  public A removeMatchingFromListeners(Predicate<ListenerStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildListeners instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ListenerStatus> getListeners();
  public List<ListenerStatus> buildListeners();
  public ListenerStatus buildListener(Integer index);
  public ListenerStatus buildFirstListener();
  public ListenerStatus buildLastListener();
  public ListenerStatus buildMatchingListener(Predicate<ListenerStatusBuilder> predicate);
  public Boolean hasMatchingListener(Predicate<ListenerStatusBuilder> predicate);
  public A withListeners(List<ListenerStatus> listeners);
  public A withListeners(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ListenerStatus... listeners);
  public Boolean hasListeners();
  public GatewayStatusFluent.ListenersNested<A> addNewListener();
  public GatewayStatusFluent.ListenersNested<A> addNewListenerLike(ListenerStatus item);
  public GatewayStatusFluent.ListenersNested<A> setNewListenerLike(Integer index,ListenerStatus item);
  public GatewayStatusFluent.ListenersNested<A> editListener(Integer index);
  public GatewayStatusFluent.ListenersNested<A> editFirstListener();
  public GatewayStatusFluent.ListenersNested<A> editLastListener();
  public GatewayStatusFluent.ListenersNested<A> editMatchingListener(Predicate<ListenerStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AddressesNested<N> extends Nested<N>,GatewayAddressFluent<GatewayStatusFluent.AddressesNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ListenersNested<N> extends Nested<N>,ListenerStatusFluent<GatewayStatusFluent.ListenersNested<N>>{
    public N and();
    public N endListener();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/GatewayStatusFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewayStatusFluent<A extends GatewayStatusFluent<A>> extends Fluent<A>{
  public A addToAddresses(int index,GatewayAddress item);
  public A setToAddresses(int index,GatewayAddress item);
  public A addToAddresses(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewayAddress... items);
  public A addAllToAddresses(Collection<GatewayAddress> items);
  public A removeFromAddresses(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewayAddress... items);
  public A removeAllFromAddresses(Collection<GatewayAddress> items);
  public A removeMatchingFromAddresses(Predicate<GatewayAddressBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAddresses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<GatewayAddress> getAddresses();
  public List<GatewayAddress> buildAddresses();
  public GatewayAddress buildAddress(int index);
  public GatewayAddress buildFirstAddress();
  public GatewayAddress buildLastAddress();
  public GatewayAddress buildMatchingAddress(Predicate<GatewayAddressBuilder> predicate);
  public Boolean hasMatchingAddress(Predicate<GatewayAddressBuilder> predicate);
  public A withAddresses(List<GatewayAddress> addresses);
  public A withAddresses(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.GatewayAddress... addresses);
  public Boolean hasAddresses();
  public A addNewAddress(String type,String value);
  public GatewayStatusFluent.AddressesNested<A> addNewAddress();
  public GatewayStatusFluent.AddressesNested<A> addNewAddressLike(GatewayAddress item);
  public GatewayStatusFluent.AddressesNested<A> setNewAddressLike(int index,GatewayAddress item);
  public GatewayStatusFluent.AddressesNested<A> editAddress(int index);
  public GatewayStatusFluent.AddressesNested<A> editFirstAddress();
  public GatewayStatusFluent.AddressesNested<A> editLastAddress();
  public GatewayStatusFluent.AddressesNested<A> editMatchingAddress(Predicate<GatewayAddressBuilder> predicate);
  public A addToConditions(int index,Condition item);
  public A setToConditions(int index,Condition item);
  public A addToConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.kubernetes.api.model.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public List<Condition> getConditions();
  public Condition getCondition(int index);
  public Condition getFirstCondition();
  public Condition getLastCondition();
  public Condition getMatchingCondition(Predicate<Condition> predicate);
  public Boolean hasMatchingCondition(Predicate<Condition> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.kubernetes.api.model.Condition... conditions);
  public Boolean hasConditions();
  public A addToListeners(int index,ListenerStatus item);
  public A setToListeners(int index,ListenerStatus item);
  public A addToListeners(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ListenerStatus... items);
  public A addAllToListeners(Collection<ListenerStatus> items);
  public A removeFromListeners(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ListenerStatus... items);
  public A removeAllFromListeners(Collection<ListenerStatus> items);
  public A removeMatchingFromListeners(Predicate<ListenerStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildListeners instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ListenerStatus> getListeners();
  public List<ListenerStatus> buildListeners();
  public ListenerStatus buildListener(int index);
  public ListenerStatus buildFirstListener();
  public ListenerStatus buildLastListener();
  public ListenerStatus buildMatchingListener(Predicate<ListenerStatusBuilder> predicate);
  public Boolean hasMatchingListener(Predicate<ListenerStatusBuilder> predicate);
  public A withListeners(List<ListenerStatus> listeners);
  public A withListeners(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ListenerStatus... listeners);
  public Boolean hasListeners();
  public GatewayStatusFluent.ListenersNested<A> addNewListener();
  public GatewayStatusFluent.ListenersNested<A> addNewListenerLike(ListenerStatus item);
  public GatewayStatusFluent.ListenersNested<A> setNewListenerLike(int index,ListenerStatus item);
  public GatewayStatusFluent.ListenersNested<A> editListener(int index);
  public GatewayStatusFluent.ListenersNested<A> editFirstListener();
  public GatewayStatusFluent.ListenersNested<A> editLastListener();
  public GatewayStatusFluent.ListenersNested<A> editMatchingListener(Predicate<ListenerStatusBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AddressesNested<N> extends Nested<N>,GatewayAddressFluent<GatewayStatusFluent.AddressesNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface ListenersNested<N> extends Nested<N>,ListenerStatusFluent<GatewayStatusFluent.ListenersNested<N>>{
    public N and();
    public N endListener();
    
  }
  
}
